==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Address book name" : "Nombre de libreta de direcciones",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Añadiendo campo ...",
    "Import" : "Importar",
    "Add contact" : "Añadir contacto",
    "No search result for {query}" : "Sin resultados para {query}",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "Post Office Box" : "Buzón de correo",
    "Postal Code" : "Código Postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "Invalid file type." : "Tipo de archivo inválido",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Inicio",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "nº de Fax",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/es.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Address book name" : "Nombre de libreta de direcciones",
    "No contacts in here" : "No hay contactos aquí",
    "Name" : "Nombre",
    "Organization" : "Organización",
    "Title" : "Título",
    "Add field ..." : "Añadiendo campo ...",
    "Import" : "Importar",
    "Add contact" : "Añadir contacto",
    "No search result for {query}" : "Sin resultados para {query}",
    "All contacts" : "Todos los contactos",
    "Not grouped" : "No agrupado",
    "Post Office Box" : "Buzón de correo",
    "Postal Code" : "Código Postal",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Country" : "País",
    "Address" : "Dirección",
    "(new group)" : "(nuevo grupo)",
    "New contact" : "Nuevo contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
    "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solamente se permiten archivos VCard.",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Groups" : "Grupos",
    "Birthday" : "Fecha de nacimiento",
    "Email" : "Correo electrónico",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax hogareño",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Social Network" : "Red social",
    "Settings" : "Ajustes"
},
"nplurals=2; plural=(n != 1);");
